# Anguelova_2024

Title: Technical note: Post-processing deep neural network for performance improvement of interictal epileptiform discharges detection

Summary:
In this study we aimed to further improve interictal epileptiform discharges (IED) detection performance of a deep neural network based algorithm with a second-level post-processing deep learning network. Seventeen interictal ambulatory EEGs were used, 15 with focal and 2 with generalized epilepsy in patients of age range 4-80 years (median 19y, 25th-75th percentile 14-32y). The EEG data was split into 2s non-overlapping epochs. Epochs with an IED probability of at least 0.99, according to a previously developed VGG-C based convolutional neural network, were preselected for the second-level 2D convolutional neural network (CNN). The selected epochs were used as input for the second-level post-processing CNN in Python; these are uploaded as a dataset in this repository. Data was divided into an 80/20 training/validation, resulting in 3049 epochs for training/validation and 580 epochs for testing.

Software:
Matlab R2021a (The MathWorks, Inc., Natick, MA) 
Python 3.10 using Keras 2.6.0, Tensorflow 2.8.0 and scikit-learn 1.0.2


Content:

Code:
- create_dummy_var_2024_02_14.m: Create the dummy EEG variable to test the second-level network.
- plot_EEGepoch_dummy_var_2024_02_18.m: Plot the dummy EEG variable epochs.
- selection_EEGepochs_2024_02_14.m: Selection of the EEG epochs by the first-level network with a specific probability of being an IED. The first-level network is published elsewhere by da Silva et al., 2021.
- plot_EEGepoch_2024_02_18.m: Plot the EEG epochs, for scoring.
- App_2023_09_15.mlapp: MATLAB App used for scoring the EEG epochs.
- modelAn_EEG_2024_02_14.py: Deep learning model of the second-level network. The first-level network is published elsewhere by da Silva et al., 2021.
- ROC_curve_2023_09_18.m: Plotting the ROC curve for dummy EEG variable and the true EEG epochs.

Data:

We are not allowed to share the patients’ original EEG files, however, the selected EEG epochs that were used as input in our second-level deep neural network, as well as the dummy variable, are provided in the file: dataset_dummy_and_EEG_epochs.mat
- X_test and X_train are the train and test set for the dummy variable
- seizureLocation_selectie_input_train and seizureLocation_selectie_input_test are the train and test set for the EEG epochs
- DB_labels shows the labels of the 18 bipolar channels 


Authors:
Galia Valentinova Anguelova MD MSc PhD and Patricia Margaret Baines MSc

Contact information: ganguelova@sein.nl

Financial Disclosure Statement
The authors received no specific funding for this work.

References
1.	Pillai J, Sperling MR. Interictal EEG and the Diagnosis of Epilepsy. Epilepsia. 2006;47(SUPPL. 1):14–22. 
2.	Smith SJM, Smith S. EEG in the diagnosis, classification, and management of patients with epilepsy. J Neurol Neurosurg Psychiatry [Internet]. 2005;76:2–7.
3.	Lodder SS, Askamp J, van Putten MJAM. Computer-Assisted Interpretation of the EEG Background Pattern: A Clinical Evaluation. PLoS One. 2014;9(1):85966. 
4.	Lodder SS, van Putten MJAM. A Self-Adapting System for the Automated Detection of Inter-Ictal Epileptiform Discharges. PLoS One. 2014;9(1):85180. 
5.	da Silva Lourenço C, Tjepkema-Cloostermans MC, van Putten MJAM. Machine learning for detection of interictal epileptiform discharges. Vol. 132, Clinical Neurophysiology; 2021. p. 1433–43. 
6.	Wilson SB, Emerson R. Spike detection: a review and comparison of algorithms. Clinical Neurophysiology; 2002 Dec;113(12):1873-81.
7.	Tjepkema-Cloostermans MC, de Carvalho RC v, van Putten MJAM. Deep learning for detection of focal epileptiform discharges from scalp EEG recordings. Clinical Neurophysiology; 2018;129(10):2191-2196.
8.	da Silva Lourenço C, Tjepkema-Cloostermans MC, van Putten MJAM. Efficient use of clinical EEG data for deep learning in epilepsy. Clinical Neurophysiology. 2021 Jun 1;132(6):1234–40. 
9.	Rosenberg Johansen A, Jin J, Maszczyk T, Dauwels J, Cash SS, Brandon Westover M. Epileptiform spike detection via convolutional neural networks. Proc IEEE Int Conf Acoust Speech Signal Process. 2016 Mar:2016:754-758.
10.	Jing J, Sun H, Kim JA, Herlopian A, Karakis I, Ng M, et al. Development of Expert-Level Automated Detection of Epileptiform Discharges during Electroencephalogram Interpretation. JAMA Neurol. 2020 Jan 1;77(1):103–8. 
11.	Haider A, Wei Y, Liu S, Hwang SH. Pre- and post-processing algorithms with deep learning classifier for Wi-Fi fingerprint-based indoor positioning. Electronics. 2019 Feb 1;8(2). 
12.	Marechal E, Jaugey A, Tarris G, Paindavoine M, Seibel J, Martin L, et al. Automatic Evaluation of Histological Prognostic Factors Using Two Consecutive Convolutional Neural Networks on Kidney Samples. Clinical Journal of the American Society of Nephrology. 2022 Feb 1;17(2):260–70. 
13.	Cho J, Lee K, Shin E, Choy G, Do S. How much data is needed to train a medical image deep learning system to achieve necessary high accuracy? 2015 Nov 19; Available from: http://arxiv.org/abs/1511.06348
14.	Aggarwal CC. Neural Networks and Deep Learning: A Textbook. Neural Networks and Deep Learning: A Textbook. 2023 Jan 1;1–529. 
